# ide-probe has been renamed to ide-probe-mod in kernel 2.4.0
# just try both, one of them should succeed
IDE_CD_MODS="ide-mod cdrom ide-probe ide-probe-mod ide-core ide-detect ide-cd"
SCSI_CD_MODS="scsi_mod cdrom sr_mod"
IDE_HD_MODS="ide-mod ide-probe ide-probe-mod ide-core ide-detect ide-disk"
SCSI_HD_MODS="scsi_mod sd_mod"
USB_STORAGE_MODS="usbcore scsi_mod usb-storage sd_mod"

# some common functions
probe_mods() {
  for f in $@ ; do
    if insmod_helper $f ; then
      if [ "$VERBOSE" = "yes" ]; then
        if [ -e /linuxrc ]; then
          echo -e "  loaded ${COLOR_GREEN}${f}${COLOR_NORMAL} ... "
        else
          echo -e "  loaded ${COLOR_GREEN}${f}${COLOR_NORMAL} ... "
        fi
      fi
    fi
  done
}

install_ide_cd_mods() {
  probe_mods $IDE_CD_MODS
}

install_scsi_cd_mods() {
  probe_mods $SCSI_CD_MODS
}

install_ide_hd_mods() {
  probe_mods $IDE_HD_MODS
}

install_scsi_hd_mods() {
  probe_mods $SCSI_HD_MODS
}

install_usb_storage_mods() {
  probe_mods $USB_STORAGE_MODS
}

probe_scsi_mods() {
  echo "probing for scsi adapters (this may hang your system)..."
  probe_mods `cat /etc/scsiprobe.dat`
  echo "probe completed"
}

check_scsi() {
  echo "searching for installed SCSI adapters..."
  listpci |
  while read class mod desc; do
    if [ "$class" = "SCSI" ]; then
      if [ -e /linuxrc ]; then
        if [ "$VERBOSE" = "yes" ]; then
          echo -n "  found $desc ... "
        else
          echo "  found $desc ... "
        fi
      else
        if [ "$VERBOSE" = "yes" ]; then
          echo -n -e "  found $desc ... "
        else
          echo -e "  found $desc ... "
        fi
      fi
      if insmod_helper $mod ; then
        if [ "$VERBOSE" = "yes" ]; then
          if [ -e /linuxrc ]; then
            echo -e "loaded ${COLOR_GREEN}${mod}${COLOR_NORMAL} ... "
          else
            echo -e "loaded ${COLOR_GREEN}${mod}${COLOR_NORMAL} ... "
          fi
        fi
      else
        if [ -e /linuxrc ]; then
          echo -e "${COLOR_RED}load failed${COLOR_NORMAL}"
        else
          echo -e "${COLOR_RED}load failed${COLOR_NORMAL}"
        fi
      fi
    fi
  done
  echo "search completed"
}

# prints all partitions that are located on USB storage devices to stdout
get_usb_storage_partitions() {
  # this was a terrible hack, try to do it better with the new /proc support
  #local usb_storage_devices=`dmesg | grep "SCSI emulation for USB Mass Storage devices" | cut -d' ' -f1,1`
  #for dev in $usb_storage_devices; do
  #  devnum=`expr "$dev" : "scsi\(.\)"`

  for dev in `ls /proc/scsi/usb-storage-*/* 2>/dev/null`; do
    if [ "`grep "Attached" $dev | cut -c 16-19`" = "Yes" ]; then
      devnum=`expr "$dev" : "/proc/scsi/usb-storage-.*/\(.*\)"`
      grep "scsi/host${devnum}/.*/part[0-9]*" /proc/partitions | cut -c 23- | cut -d' ' -f1
    fi
  done
}
